starcluster.utils.AttributeDict

Package starcluster :: Module utils :: Class AttributeDict |
[hide private]
[frames] | no frames]

# Class AttributeDict

source code

Subclass of dict that allows read-only attribute-like access to dictionary key/values

Instance Methods | [hide private]
__getattr__(self, name) | source code
Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__init__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__setitem__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `dict`: `__hash__`

Properties | [hide private]
Inherited from `object`: `__class__`